@@ -929,7 +929,16 @@ mod tests {
             })
         }
 
-        let amt = 1000;
+        let amt;
+        #[cfg(not(miri))]
+        {
+            amt = 1000;
+        }
+        #[cfg(miri)]
+        {
+            amt = 100; // miri would take forever if we used `amt = 1000` here.
+        }
+
         let mut compressed = DefaultQueueEncoder::new();
 
         assert_eq!(compressed.len(), 0);
